# Release 0.7.8

!!!tip inline end "Need Help?"
    The SuperCowPowers team is happy to give any assistance needed when setting up AWS and Workbench. So please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8
 
Since we've recently introduced a **View()** class for DataSources and FeatureSets we needed to rename a few classes/modules.

### FeatureSets
For setting holdout ids we've changed/combined to just one method `set_training_holdouts()`, so if you're using `create_training_view()` or `set_holdout_ids()` you can now just use the unified method `set_training_holdouts()`.

There's also a change to getting the training view table method.

```
old: fs.get_training_view_table(create=False)
new: fs.get_training_view_table(), does not need the create=False
```

### Models
```
inference_predictions() --> get_inference_predictions()
```

### Web/Plugins
We've changed the Web/UI View class to 'WebView'. So anywhere where you used to have **view** just replace with **web_view**

```
from workbench.views.artifacts_view import ArtifactsView
```
is now

```
from workbench.web_interface.page_views.all_artifacts import AllArtifacts
```

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 